function varargout = DFT_Matrix(varargin)
% DFT_MATRIX MATLAB code for DFT_Matrix.fig
%      DFT_MATRIX, by itself, creates a new DFT_MATRIX or raises the existing
%      singleton*.
%
%      H = DFT_MATRIX returns the handle to a new DFT_MATRIX or the handle to
%      the existing singleton*.
%
%      DFT_MATRIX('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DFT_MATRIX.M with the given input arguments.
%
%      DFT_MATRIX('Property','Value',...) creates a new DFT_MATRIX or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before DFT_Matrix_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to DFT_Matrix_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help DFT_Matrix

% Last Modified by GUIDE v2.5 20-Nov-2010 13:34:07

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @DFT_Matrix_OpeningFcn, ...
                   'gui_OutputFcn',  @DFT_Matrix_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before DFT_Matrix is made visible.
function DFT_Matrix_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to DFT_Matrix (see VARARGIN)

% Choose default command line output for DFT_Matrix
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% This sets up the initial plot - only do when we are invisible
% so window can get raised using DFT_Matrix.
draw_DFT_Matrix( handles, str2num( get(handles.DFT_size, 'String' ) ) ) ;

set( handles.figure1, 'Units', 'pixels' ) ;

screen_dims = get( 0, 'screensize' ) ;

win = get( handles.figure1 ) ;

Position(1) = floor( (screen_dims(3) - win.Position(3)) / 2 ) ;
Position(2) = floor( (screen_dims(4) - win.Position(4)) / 2 ) ;
Position(3) = win.Position(3) ;
Position(4) = win.Position(4) ;

set( handles.figure1, 'Position', Position );

% UIWAIT makes DFT_Matrix wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = DFT_Matrix_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

draw_DFT_Matrix( handles, str2num( get(handles.DFT_size, 'String' ) ) )

DFT_size=16;

function draw_DFT_Matrix( handles, DFT_size ) ;

axes(handles.axes1);
cla;

DFT_matrix = dftmtx( DFT_size ) ;

spacing = 1/(DFT_size+1) ;

increment = linspace(0,1,ceil(DFT_size^(1/3)));

eval( ['[', sprintf('C%g, ',1:3), '] = ndgrid( increment ) ;'] )
eval( [ 'colors = [' sprintf( 'C%g(:), ', 1:3), '] ;' ] ) ;

axis off
grid on

box_size = 0.8*spacing/2 ;

t = (1/32:1/16:1)'*2*pi;
x = sin(t) * box_size ;
y = cos(t) * box_size ;

hold on

if DFT_size < 25
    
    fill( [ 0 1 1 0 0 ]*0.95+0.025 , [ 0 0 1 1 0 ]*0.95+0.025 , 'w' ) ;

    for i = 1:DFT_size
        for j = 1:DFT_size
            
            DFT_entry = round( ( angle( DFT_matrix(i,j) ) + pi ) / ( 2*pi / DFT_size ) ) + 1 ;
            
            if DFT_entry > DFT_size
                DFT_entry = 1 ;
            end
            
            fill( spacing*i + x, spacing*j + y, colors( DFT_entry, : ) ) ;
            
        end
    end
    
else

    fill( [ 0 1 1 0 0 ], [ 0 0 1 1 0 ] , 'w' ) ;

    for i = 1:DFT_size
        for j = 1:DFT_size

            DFT_entry = round( ( angle( DFT_matrix(i,j) ) + pi ) / ( 2*pi / DFT_size ) ) + 1 ;

            if DFT_entry > DFT_size
                DFT_entry = 1 ;
            end

            plot( spacing*i, spacing*j, '.', 'Color', colors( DFT_entry, : ), 'MarkerSize', 10 ) ;     

        end
    end

end

hold off



% --------------------------------------------------------------------
function FileMenu_Callback(hObject, eventdata, handles)
% hObject    handle to FileMenu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function OpenMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to OpenMenuItem (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
file = uigetfile('*.fig');
if ~isequal(file, 0)
    open(file);
end

% --------------------------------------------------------------------
function PrintMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to PrintMenuItem (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
printdlg(handles.figure1)

% --------------------------------------------------------------------
function CloseMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to CloseMenuItem (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
selection = questdlg(['Close ' get(handles.figure1,'Name') '?'],...
                     ['Close ' get(handles.figure1,'Name') '...'],...
                     'Yes','No','Yes');
if strcmp(selection,'No')
    return;
end

delete(handles.figure1)


% --- Executes on selection change in popupmenu1.
function popupmenu1_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu1 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu1


% --- Executes during object creation, after setting all properties.
function popupmenu1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
     set(hObject,'BackgroundColor','white');
end

set(hObject, 'String', {'plot(rand(5))', 'plot(sin(1:0.01:25))', 'bar(1:.5:10)', 'plot(membrane)', 'surf(peaks)'});



function DFT_size_Callback(hObject, eventdata, handles)
% hObject    handle to DFT_size (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of DFT_size as text
%        str2double(get(hObject,'String')) returns contents of DFT_size as a double


% --- Executes during object creation, after setting all properties.
function DFT_size_CreateFcn(hObject, eventdata, handles)
% hObject    handle to DFT_size (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
